import React, { useState, useEffect } from "react";
import axios from "axios";
import { toast, ToastContainer } from "react-toastify";
import "react-toastify/dist/ReactToastify.css";

export const ElectronicTab = () => {
  const [selectedTabIdx, setSelectedTabIdx] = useState(0);
  const [consentId, setConsentId] = useState(null);
  const [consentData, setConsentData] = useState({
    assetHolderId: "66878ffd55c588b565f21684",
    consentTerms: false,
    consentTaxNotification: false,
  });

  useEffect(() => {
    const fetchConsent = async () => {
      try {
        const response = await axios.get(
          "${process.env.NEXT_PUBLIC_BASE_URL}/assetHolderConsent/66878ffd55c588b565f21684"
        );
        setConsentData(response.data);
        setConsentId(response.data._id);
      } catch (error) {
        console.error("Error fetching consent:", error);
      }
    };

    fetchConsent();
  }, []);

  const handleChange = (e) => {
    const { name, checked } = e.target;
    setConsentData((prevData) => ({
      ...prevData,
      [name]: checked,
    }));
  };

  const handleSave = async () => {
    try {
      if (consentId) {
        await axios.patch(
          `${process.env.NEXT_PUBLIC_BASE_URL}/assetHolderConsent/update/${consentId}`,
          consentData
        );
        toast.success("Consent updated successfully");
      } else {
        const response = await axios.post(
          "${process.env.NEXT_PUBLIC_BASE_URL}/assetHolderConsent/add",
          consentData
        );
        toast.success("Consent created successfully");
        setConsentId(response.data._id);
      }
    } catch (error) {
      toast.error("An error occurred while saving consent");
    }
  };

  const tabs = [
    { name: "Electronic Consent", current: true },
    { name: "Purpose", current: false },
    { name: "Risks", current: false },
    { name: "Expectations", current: false },
  ];

  return (
    <>
      <ToastContainer />
      <span className="text-lg text-prussianBlue/40 mb-4 block">
        Electronic Consent
      </span>
      <div className="custom-shadow rounded">
        <div className="primary-gradient border border-black rounded px-12 overflow-x-auto">
          <nav className="flex justify-between gap-3 w-full" aria-label="Tabs">
            {tabs.map((tab, i) => (
              <a
                key={tab.name}
                className={`${
                  i === selectedTabIdx
                    ? "text-white border-b-4 border-white focus:outline-none "
                    : ""
                } whitespace-nowrap py-4 cursor-pointer text-xl`}
                onClick={() => setSelectedTabIdx(i)}
              >
                {tab.name}
              </a>
            ))}
          </nav>
        </div>
        {(selectedTabIdx === 0 ||
          selectedTabIdx === 1 ||
          selectedTabIdx === 2 ||
          selectedTabIdx === 3) && (
          <div className="p-10">
            <p className="mb-6">
              {
                "Lorem ipsum is derived from the Latin “dolorem ipsum” roughly translated as “pain itself.” Lorem ipsum presents the sample font and orientation of writing on web pages and other software applications where content is not the main concern of the developer.Lorem ipsum is derived from the Latin"
              }
            </p>
            <h2 className="text-prussianBlue mb-4 font-medium text-lg">
              Purpose
            </h2>
            <p className="mb-3">
              {
                "Lorem ipsum is derived from the Latin “dolorem ipsum” roughly translated as “pain itself.” Lorem ipsum presents the sample font and orientation of writing on web pages and other software applications where content is not the main concern of the developer.Lorem ipsum is derived from the Latin"
              }
            </p>
            <p className="mb-6">
              {
                "Lorem ipsum presents the sample font and orientation of writing on web pages and other software applications where content is not the main concern of the developer."
              }
            </p>
            <h2 className="text-prussianBlue mb-4 font-medium text-lg">
              Risks
            </h2>
            <p className="mb-6">
              {
                "Lorem ipsum is derived from the Latin “dolorem ipsum” roughly translated as “pain itself.” Lorem ipsum presents the sample font and orientation of writing on web pages and other software applications where content is not the main concern of the developer.Lorem ipsum is derived from the Latin"
              }
            </p>
            <h2 className="text-prussianBlue mb-4 font-medium text-lg">
              Expectations
            </h2>
            <p className="mb-6">
              {
                "Lorem ipsum is derived from the Latin “dolorem ipsum” roughly translated as “pain itself.” Lorem ipsum presents the sample font and orientation of writing on web pages and other software applications where content is not the main concern of the developer.Lorem ipsum is derived from the Latin"
              }
            </p>
            <label htmlFor="consentTerms" className="cursor-pointer mb-4 block">
              <input
                type="radio"
                id="consentTerms"
                name="consentTerms"
                className="me-4"
                checked={consentData.consentTerms}
                onChange={handleChange}
              />
              Lorem ipsum presents the sample font and orientation of writing on
              web pages and other software applications where content is not the
              main concern of the developer.
            </label>
            <label
              htmlFor="consentTaxNotification"
              className="cursor-pointer mb-10 block"
            >
              <input
                type="radio"
                id="consentTaxNotification"
                name="consentTaxNotification"
                className="me-4"
                checked={consentData.consentTaxNotification}
                onChange={handleChange}
              />
              Software applications where content is not the main concern of the
              developer.
            </label>
            <div className="flex justify-end">
              <button
                className="py-2 px-7 primary-gradient rounded text-white"
                onClick={handleSave}
              >
                Save
              </button>
            </div>
          </div>
        )}
      </div>
    </>
  );
};
